
from dubious import discord
===========================

.. automodule:: dubious.discord
    :members:

.. toctree::
    :maxdepth: 2
    :caption: Contents

    discord/disc
    discord/api
    discord/req